@@ -62,3 +62,6 @@ class NodeDataType(TypedDict, total=False):
     statistics: NodeStatisticsDataType
     highestSecurityClass: int
     isControllerNode: bool
+    lastSeen: str
+    defaultVolume: int | float | None
+    defaultTransitionDuration: int | float | None
